%Patrick Kano
%
%November 8, 2005
%
%Purpose: Dialog Box for the Matrix Weeks Method
%       : Computes the exponential from the Higham's gallery
%
%References:
%
%Kano, P.,M. Brio, and J. Moloney.  ``Application of Weeks method for the numerical inversion of
%the Laplace transform to the matrix exponential", Communications in mathematical sciences", vol. 3, no. 3,
%pp. 335-372, 2005.
%
%Matlab Gallery of Matrices
%http://www.mathworks.com/access/helpdesk/help/techdoc/ref/gallery.html
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;
close all;

%Global variables for the output to the user
global ExpMatrix;
global SigmaWeeks;
global BetaWeeks;
global EstimatedTotalError;
global TruncationError;
global RoundoffError;

%Description of the Dialog Box Variables
prompt = {...
'Gallery Matrix Name',...
'Matrix Size',...
'Number of Coefficients',...
'Parameter Algorithm 1)MinMax  2)Pseudospectral  3)Weideman',...
'Sigma Distance',...
'Delta Sigma',...
'Minimum b  (b>0)',...
'Maximum b',...
'Delta b',...
'Error Switch 1)On 0)Off',...
'FFT or Midpoint Coefficient Algorithm 1)FFT 0)Midpoint'};

%Default Values for Dialog Box Variables
defaultValues = {...
'pei',... %Gallery Matrix Name
'5',...   %Square Matrix Size
'16',...  %Number of Coefficients
'1',...   %Parameter Algorithm 1)MinMax, 2)Pseudo, 3)Weideman
'10',...  %Sigma Distance
'0.1',... %Delta Sigma
'0.1',... %Minimum b  (b>0)
'10',...  %Maximum b
'0.1',... %Delta b
'0',...	  %Error Switch
'1'};     %FFT or Midpoint Coefficient Algorithm 1)FFT 0)Midpoint

%Dialog Box Variables
fields = {...
'MatrixName',...
'MatrixSize',...
'NLaguerreCoef',...
'ParameterSwitch',...
'SigmaDistance',...
'DeltaSigma',...
'BetaMin',...
'BetaMax',...
'DeltaBeta',...
'ErrorSwitch',...
'LagSwitch'};

%Dialog Box Options
Title = 'Matrix Weeks Method';
lineNo = 0.8;
AddOpts.Resize = 'off';	         %Allows user to resize the dialog box
AddOpts.WindowStyle = 'normal';  %Modal vs normal have different user responses
AddOpts.Interpreter = 'tex';     %Interpret input strings as tex

%Create Dialog Box
inputdata = inputdlg(prompt,Title,lineNo,defaultValues,AddOpts);

%Check if user hit cancel
if(~isempty(inputdata)) 	
 inputdata = cell2struct(inputdata,fields);  %Assign names to the values in the inputdata
 
 %Convert strings to numbers if necessary
 MatrixName = inputdata.MatrixName;
 MatrixSize = str2num(inputdata.MatrixSize);
 NLaguerreCoef = str2num(inputdata.NLaguerreCoef);
 ParameterSwitch = str2num(inputdata.ParameterSwitch);
 SigmaDistance = str2num(inputdata.SigmaDistance);
 DeltaSigma = str2num(inputdata.DeltaSigma);
 BetaMin = str2num(inputdata.BetaMin);
 BetaMax = str2num(inputdata.BetaMax);
 DeltaBeta = str2num(inputdata.DeltaBeta);
 ErrorSwitch = str2num(inputdata.ErrorSwitch);
 LagSwitch = str2num(inputdata.LagSwitch);

end
Amatrix = gallery(MatrixName,MatrixSize)
 
%Run the Matrix Exponential Code
[ExpMatrix,SigmaWeeks,BetaWeeks,DiagVec,EstimatedTotalError,TruncationError,RoundoffError] =...
MWeeksExpMainPub(Amatrix,NLaguerreCoef,ParameterSwitch,SigmaDistance,DeltaSigma,BetaMin,BetaMax,DeltaBeta,ErrorSwitch,LagSwitch)

%Plot Eigenvalues in S-Space
subplot(1,2,1);
plot(real(DiagVec),imag(DiagVec),'bo');
title('S-Plane');
xlabel('real axis');
ylabel('imaginary axis');

%Plot Mapped Eigenvalues in W-Space
MappedEigenvalues = (DiagVec-SigmaWeeks-BetaWeeks)./(DiagVec-SigmaWeeks+BetaWeeks)

subplot(1,2,2);
ezplot('sin(t)','cos(t)');
hold on;
plot(real(MappedEigenvalues),imag(MappedEigenvalues),'go');
title('W-Plane');
xlabel('real axis');
ylabel('imaginary axis');

%return;
