%P. Kano
%November 1, 2005

function [MinDenom] = WeeksPseudorminGamma(Theta,SigmaWeeks,BetaWeeks,rmin,Trianmatrix)

warning off; %Supress warnings, comment this line to investigate robustness

%Uses ideas from: Trefethen, Acta Numerica, 1999
%Note SigmaWeeks ~= sig the singular value
%Use Inverse Lanczos Iteration to Determine Smallest Singular Value
%The number of inversions required for the Lanczos Iteration and the Maximization
%is almost certainly less than required by direct doubling of the inversions.

NNodes = size(Trianmatrix,2);
Wtemp = rmin*exp(i*Theta);
SofW = SigmaWeeks-BetaWeeks+ (2*BetaWeeks/(1-Wtemp));
T1 = SofW*eye(NNodes)-Trianmatrix;
T2 = T1';
 
sigold = 0; qold = zeros(NNodes,1); beta = 0; H = [];
q = randn(NNodes,1) + sqrt(-1)*randn(NNodes,1); q=q/norm(q);
for k=1:99
  v = T1\(T2\q) - beta*qold;
  alpha = real(q'*v); v = v - alpha*q;
  beta = norm(v); qold = q; q = v/beta;
  H(k+1,k) = beta; H(k,k+1) = beta; H(k,k) = alpha;
  sig = max(eig(H(1:k,1:k)));
  if (abs(sigold/sig-1)<0.001) | (sig<3 & k>2) break, end
  sigold = sig;
  end
sigmin = 1/sqrt(sig);
MinDenom = sigmin;

MinDenom = abs(1-Wtemp)/(2*BetaWeeks)*MinDenom;


